@@ -707,7 +707,8 @@ impl KOFileDebug {
                 stream.set_color(type_color)?;
                 match value {
                     kerbalobjects::KOSValue::Null => {
-                        writeln!(stream, "NULL")?;
+                        write!(stream, "NULL")?;
+                        stream.set_color(regular_color)?;
                     }
                     kerbalobjects::KOSValue::Bool(b) => {
                         write!(stream, "{:<12}", "BOOL")?;
@@ -754,6 +755,7 @@ impl KOFileDebug {
                     }
                     kerbalobjects::KOSValue::ArgMarker => {
                         write!(stream, "{:<12}", "ARGMARKER")?;
+                        stream.set_color(regular_color)?;
                     }
                     kerbalobjects::KOSValue::ScalarInt(i) => {
                         write!(stream, "{:<12}", "SCALARINT")?;
